@@ -50,6 +50,7 @@
 #include <KColorCombo>
 #include <KHelpClient>
 #include <KRecentDirs>
+#include <KMessageWidget>
 
 #ifdef ENABLE_KNEWSTUFF3
 #if KNEWSTUFF_VERSION < QT_VERSION_CHECK(5, 91, 0)
@@ -80,6 +81,7 @@
 #include <QApplication>
 #include <QTimer>
 #include <QFileDialog>
+#include <QSignalBlocker>
 
 namespace {
   static const int CONFIG_MIN_WIDTH = 640;
@@ -239,10 +241,21 @@ void ConfigDialog::initGeneralPage(QFrame* frame) {
                                    "cause Tellico to run slowly, stored in the Tellico "
                                    "application directory, or stored in a directory in the "
                                    "same location as the data file."));
+  connect(m_rbImageInFile, &QRadioButton::toggled, this, &ConfigDialog::slotUpdateImageLocationLabel);
+  connect(m_rbImageInAppDir, &QRadioButton::toggled, this, &ConfigDialog::slotUpdateImageLocationLabel);
+  connect(m_rbImageInLocalDir, &QRadioButton::toggled, this, &ConfigDialog::slotUpdateImageLocationLabel);
+  m_mwImageLocation = new KMessageWidget(imageGroupBox);
+  m_mwImageLocation->setMessageType(KMessageWidget::Information);
+  m_mwImageLocation->hide();
+  m_mwImageLocation->setWordWrap(true);
+  m_infoTimer = new QTimer(imageGroupBox);
+  m_infoTimer->setInterval(5000);
+  m_infoTimer->callOnTimeout(m_mwImageLocation, &KMessageWidget::animatedHide);
   QVBoxLayout* imageGroupLayout = new QVBoxLayout(imageGroupBox);
   imageGroupLayout->addWidget(m_rbImageInFile);
   imageGroupLayout->addWidget(m_rbImageInAppDir);
   imageGroupLayout->addWidget(m_rbImageInLocalDir);
+  imageGroupLayout->addWidget(m_mwImageLocation);
   imageGroupBox->setLayout(imageGroupLayout);
 
   QButtonGroup* imageGroup = new QButtonGroup(frame);
@@ -704,6 +717,10 @@ void ConfigDialog::readGeneralConfig() {
   m_cbEnableWebcam->setEnabled(false);
 #endif
 
+  // block signals temporarily so the image location label isn't shown initially
+  const QSignalBlocker block1(m_rbImageInFile);
+  const QSignalBlocker block2(m_rbImageInAppDir);
+  const QSignalBlocker block3(m_rbImageInLocalDir);
   switch(Config::imageLocation()) {
     case Config::ImagesInFile: m_rbImageInFile->setChecked(true); break;
     case Config::ImagesInAppDir: m_rbImageInAppDir->setChecked(true); break;
@@ -1213,3 +1230,54 @@ void ConfigDialog::slotCreateConfigWidgets() {
     }
   }
 }
+
+void ConfigDialog::slotUpdateImageLocationLabel() {
+  int newImageLocation;
+  if(m_rbImageInFile->isChecked()) {
+    newImageLocation = Config::ImagesInFile;
+  } else if(m_rbImageInAppDir->isChecked()) {
+    newImageLocation = Config::ImagesInAppDir;
+  } else {
+    newImageLocation = Config::ImagesInLocalDir;
+  }
+
+  const QString fileName = Kernel::self()->URL().fileName();
+  const QString imageDir = ImageFactory::imageDir().toString(QUrl::PreferLocalFile);
+  QString locationText;
+  if(newImageLocation == Config::imageLocation()) {
+    if(newImageLocation == Config::ImagesInFile) {
+      locationText = i18nc("%1 refers to the file name",
+                           "Images are currently saved within <em>%1</em>",
+                           fileName);
+    } else {
+      locationText = i18nc("%1 refers to a directory",
+                           "Images are currently saved to <em>%1</em>",
+                           imageDir);
+    }
+  } else {
+    if(newImageLocation == Config::ImagesInFile) {
+      locationText = i18nc("%1 refers to a directory, %2 to a file name",
+                           "Images will be moved from <em>%1</em> to <em>%2</em>",
+                           imageDir, fileName);
+    } else if(Config::imageLocation() == Config::ImagesInFile) {
+      locationText = i18nc("%1 refers to a file name, %2 to a directory",
+                           "Images will be moved from <em>%1</em> to <em>%2</em>",
+                           fileName, imageDir);
+    } else {
+      QString newImageDir;
+      if(newImageLocation == Config::ImagesInAppDir) {
+        newImageDir = ImageFactory::dataDir().toString(QUrl::PreferLocalFile);
+      } else {
+        newImageDir = ImageFactory::localDir().toString(QUrl::PreferLocalFile);
+      }
+      locationText = i18nc("%1 and %2 are both directories",
+                           "Images will be moved from <em>%1</em> to <em>%2</em>",
+                           imageDir, newImageDir);
+    }
+  }
+  m_mwImageLocation->setText(locationText);
+  if(!m_mwImageLocation->isVisible()) {
+    m_mwImageLocation->animatedShow();
+  }
+  m_infoTimer->start();
+}
