@@ -210,7 +210,7 @@ void ItunesFetcher::slotComplete(KJob* job_) {
     return;
   }
 
-  QJsonArray results = doc.object().value(QLatin1String("results")).toArray();
+  const auto results = doc.object().value(QLatin1String("results")).toArray();
   if(results.isEmpty()) {
     myDebug() << "iTunesFetcher: no results";
     stop();
@@ -245,7 +245,7 @@ void ItunesFetcher::slotComplete(KJob* job_) {
   }
 
   QList<FetchResult*> fetchResults;
-  foreach(const QJsonValue& result, results) {
+  for(const QJsonValue& result : results) {
     auto obj = result.toObject();
     if(obj.value(QLatin1String("kind")) == QLatin1String("song")) {
       readTrackInfo(obj.toVariantMap());
@@ -296,8 +296,8 @@ Tellico::Data::EntryPtr ItunesFetcher::fetchEntryHook(uint uid_) {
       f.close();
 #endif
       QJsonDocument doc = QJsonDocument::fromJson(job->data());
-      QJsonArray results = doc.object().value(QLatin1String("results")).toArray();
-      foreach(const QJsonValue& result, results) {
+      const auto results = doc.object().value(QLatin1String("results")).toArray();
+      for(const QJsonValue& result : results) {
         auto obj = result.toObject();
         if(obj.value(QLatin1String("wrapperType")) == QLatin1String("track")) {
           readTrackInfo(obj.toVariantMap());
@@ -367,12 +367,20 @@ void ItunesFetcher::populateEntry(Data::EntryPtr entry_, const QVariantMap& resu
     QString title = mapValue(resultMap_, "collectionName");
     if(title.isEmpty()) title = mapValue(resultMap_, "trackName");
     entry_->setField(QStringLiteral("title"), title);
-    entry_->setField(QStringLiteral("author"), mapValue(resultMap_, "artistName"));
+    // sometimes authors are separated by comma or ampersand
+    static const QRegularExpression authorSplitRx(QStringLiteral("\\s*[,&]\\s+"));
+    const auto authorString = mapValue(resultMap_, "artistName");
+    const auto authors = authorString.split(authorSplitRx);
+    entry_->setField(QStringLiteral("author"), authors.join(FieldFormat::delimiterString()));
     entry_->setField(QStringLiteral("plot"), mapValue(resultMap_, "description"));
     static const QRegularExpression publisherRx(QStringLiteral("^© \\d{4} (.+)$"));
     auto publisherMatch = publisherRx.match(mapValue(resultMap_, "copyright"));
     if(publisherMatch.hasMatch()) {
-      entry_->setField(QStringLiteral("publisher"), publisherMatch.captured(1));
+      QString pub = publisherMatch.captured(1);
+      if(pub.startsWith(QLatin1String("by "))) {
+        pub = pub.mid(3);
+      }
+      entry_->setField(QStringLiteral("publisher"), pub);
     }
   } else if(collectionType() == Data::Collection::Album) {
     entry_->setField(QStringLiteral("title"), mapValue(resultMap_, "collectionName"));
@@ -472,8 +480,8 @@ void ItunesFetcher::populateEpisodes(Data::EntryPtr entry_) {
   static const QRegularExpression seasonRx(QStringLiteral("Season (\\d+)"));
   QMap<int, QString> episodeMap; // mapping episode number to episode string
   QJsonDocument doc = QJsonDocument::fromJson(job->data());
-  QJsonArray results = doc.object().value(QLatin1String("results")).toArray();
-  foreach(const QJsonValue& result, results) {
+  const auto results = doc.object().value(QLatin1String("results")).toArray();
+  for(const QJsonValue& result : results) {
     auto map = result.toObject().toVariantMap();
     if(mapValue(map, "kind") != QStringLiteral("tv-episode")) continue;
     int seasonNumber = 1;
