@@ -28,7 +28,11 @@
 #include <QRegularExpression>
 #include <QTextStream>
 #include <QXmlStreamReader>
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
 #include <QTextCodec>
+#else
+#include <QStringDecoder>
+#endif
 
 using Tellico::XMLHandler;
 
@@ -40,7 +44,7 @@ bool XMLHandler::setUtf8XmlEncoding(QString& text_) {
   QString firstLine = stream.readLine();
   QRegularExpressionMatch match = rx.match(firstLine);
   if(match.hasMatch() &&
-     match.capturedRef(1).compare(QLatin1String("utf-8"), Qt::CaseInsensitive) != 0) {
+     match.captured(1).compare(QLatin1String("utf-8"), Qt::CaseInsensitive) != 0) {
     firstLine.replace(rx, QStringLiteral("encoding=\"utf-8\""));
     text_ = firstLine + QLatin1Char('\n') + stream.readAll();
     return true;
@@ -54,17 +58,25 @@ QString XMLHandler::readXMLData(const QByteArray& data_) {
   while(!reader.isStartDocument() && !reader.atEnd()) {
     reader.readNext();
   }
-  QStringRef enc = reader.documentEncoding();
+  auto enc = reader.documentEncoding();
   if(enc.isEmpty() || enc.compare(QLatin1String("utf-8"), Qt::CaseInsensitive) == 0) {
     // default to utf8 and no need to parse to change embedded encoding
     return QString::fromUtf8(data_);
   }
 
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
   QTextCodec* codec = QTextCodec::codecForName(enc.toUtf8());
   if(!codec) {
     return QString::fromUtf8(data_);
   }
   QString text = codec->toUnicode(data_);
+#else
+  QStringDecoder decoder(enc.toUtf8());
+  if(!decoder.isValid()) {
+    return QString::fromUtf8(data_);
+  }
+  QString text = decoder.decode(data_);
+#endif
   // since we always process XML files as utf-8, make sure the embedded encoding is set to utf-8
   if(!setUtf8XmlEncoding(text)) {
     myDebug() << "Found non utf-8 encoding but did not change the embedded declaration" << enc;
